===========
 Changelog
===========

2.3 (2017-04-08)
================

- Include test code in coverage analysis.

- Add CI.


2.2 (2017-01-07)
================

- Bring branch test coverage to 100 %.


2.1 (2016-03-05)
================

- Use py.test as test runner.


2.0 (2015-04-26)
================

- Moved repository to: https://bitbucket.org/icemac/icemac.ab.importxls

- Made Python 2.7 the only supported Python version.

- Update to ``bootstrap.py`` from `zc.buildout 2.3.1`.

- Pin versions for test runs.


1.0 (2011-02-03)
================

- Updated development dependencies.

- Updated package meta data.


0.9.1 (2009-09-28)
==================

- Added `bootstrap.py` to ease the package setup.

- Fixing brown bag release: only namespace packages were installed.


0.9 (2009-09-28)
================

- Initial release.
